@@ -35,6 +35,12 @@ module ClassyPrelude
     , checkSTM
     , module Data.IORef.Lifted
     , module Data.Mutable
+      -- ** STM Channels
+    , module Control.Concurrent.STM.TBChan
+    , module Control.Concurrent.STM.TBMChan
+    , module Control.Concurrent.STM.TBMQueue
+    , module Control.Concurrent.STM.TMChan
+    , module Control.Concurrent.STM.TMQueue
       -- ** Primitive (exported since 0.9.4)
     , primToPrim
     , primToIO
@@ -79,6 +85,7 @@ module ClassyPrelude
     , stdin
     , stdout
     , stderr
+    , module Say
       -- * Concurrency
     , module Control.Concurrent.Lifted
     , yieldThread
@@ -216,6 +223,9 @@ import Data.Time
     , fromGregorian
     , formatTime
     , parseTime
+#if MIN_VERSION_time(1,5,0)
+    , parseTimeM
+#endif
     , getCurrentTime
     )
 import Data.Time.Locale.Compat (defaultTimeLocale)
@@ -234,6 +244,12 @@ import Control.Monad.Reader (MonadReader, ask, asks, ReaderT (..), Reader)
 import Data.Bifunctor
 import Data.DList (DList)
 import qualified Data.DList as DList
+import Say
+import Control.Concurrent.STM.TBChan
+import Control.Concurrent.STM.TBMChan
+import Control.Concurrent.STM.TBMQueue
+import Control.Concurrent.STM.TMChan
+import Control.Concurrent.STM.TMQueue
 
 tshow :: Show a => a -> Text
 tshow = fromList . Prelude.show
